@@ -19,6 +19,7 @@ let defaultState = {
     fontSize: "auto",
     eInkMode: false,
     defaultZoomMode: "fit to screen",
+    toggleOCRTextBoxes: false,
 };
 
 let state = JSON.parse(JSON.stringify(defaultState));
@@ -49,6 +50,7 @@ function updateUI() {
     document.getElementById('menuFontSize').value = state.fontSize;
     document.getElementById('menuEInkMode').checked = state.eInkMode;
     document.getElementById('menuDefaultZoom').value = state.defaultZoomMode;
+    document.getElementById('menuToggleOCRTextBoxes').checked = state.toggleOCRTextBoxes;
 }
 
 document.addEventListener('DOMContentLoaded', function () {
@@ -91,6 +93,7 @@ document.addEventListener('DOMContentLoaded', function () {
     });
 
     updatePage(state.page_idx);
+    initTextBoxes();
 
     if (showAboutOnStart) {
         document.getElementById('popupAbout').style.display = 'block';
@@ -104,6 +107,35 @@ function disablePanzoomOnElement(element) {
     return document.getElementById('topMenu').contains(element);
 }
 
+function initTextBoxes() {
+// Add event listeners for toggling ocr text boxes with the toggleOCRTextBoxes option.
+    let textBoxes = document.querySelectorAll('.textBox');
+    for (let i = 0; i < textBoxes.length; i++) {
+        textBoxes[i].addEventListener('click', function (e) {
+            if (state.toggleOCRTextBoxes) {
+                this.classList.add('hovered');
+                // Remove hovered state from all other .textBoxes
+                for (let j = 0; j < textBoxes.length; j++) {
+                    if (i !== j) {
+                        textBoxes[j].classList.remove('hovered');
+                    }
+                }
+            }
+        });
+    }
+// When clicking off of a .textBox, remove the hovered state.
+    document.addEventListener('click', function (e) {
+        if (state.toggleOCRTextBoxes) {
+            if (e.target.closest('.textBox') === null) {
+                let textBoxes = document.querySelectorAll('.textBox');
+                for (let i = 0; i < textBoxes.length; i++) {
+                    textBoxes[i].classList.remove('hovered');
+                }
+            }
+        }
+    });
+}
+
 function updateProperties() {
     if (state.textBoxBorders) {
         r.style.setProperty('--textBoxBorderHoverColor', 'rgba(237, 28, 36, 0.3)');
@@ -119,6 +151,7 @@ function updateProperties() {
         r.style.setProperty('--textBoxDisplay', 'none');
     }
 
+
     if (state.fontSize === 'auto') {
         pc.classList.remove('textBoxFontSizeOverride');
     } else {
@@ -183,6 +216,12 @@ document.getElementById('menuEInkMode').addEventListener('click', function () {
     }
 }, false);
 
+document.getElementById('menuToggleOCRTextBoxes').addEventListener('click', function () {
+    state.toggleOCRTextBoxes = document.getElementById("menuToggleOCRTextBoxes").checked;
+    saveState();
+    updateProperties();
+}, false);
+
 document.getElementById('menuOriginalSize').addEventListener('click', zoomOriginal, false);
 document.getElementById('menuFitToWidth').addEventListener('click', zoomFitToWidth, false);
 document.getElementById('menuFitToScreen').addEventListener('click', zoomFitToScreen, false);
